@@ -77,6 +77,7 @@ async def call_external_command_async(
     debug_log_handler: OutputHandler = NO_OUTPUT,
     error_log_handler: OutputHandler = NO_OUTPUT,
 ) -> int:
+    env = dict(env)
     # await add_log(
     #     perftest_id,
     #     LogLevel.DEBUG,
@@ -139,3 +140,23 @@ async def call_external_command_async(
             f"Command exited with exitcode {proc.returncode}",
         )
         return proc.returncode
+
+
+def is_naive_dt(v: datetime) -> bool:
+    return v.tzinfo is None
+
+
+def is_non_naive_dt(v: datetime) -> bool:
+    return v.tzinfo is not None
+
+
+def is_non_naive_opt_dt(v: Optional[datetime]) -> bool:
+    return v is None or v.tzinfo is not None
+
+
+def assert_non_naive_dt(v: datetime):
+    assert v.tzinfo is not None, 'time is naive "{}"'.format(v)
+
+
+def assert_non_naive_opt_dt(v: Optional[datetime]):
+    assert v is None or v.tzinfo is not None, 'time is naive "{}"'.format(v)
